@@ -12,7 +12,9 @@
 
 #include <KAboutData>
 #include <KCrash>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
+#endif
 #include <KLocalizedString>
 
 #include <config-sweeper.h>
@@ -21,12 +23,13 @@ int main(int argc, char *argv[])
 {
    QApplication a(argc, argv);
    KLocalizedString::setApplicationDomain("sweeper");
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Kdelibs4ConfigMigrator migrator(QStringLiteral("sweeper"));
     migrator.setConfigFiles(QStringList() << QStringLiteral("sweeperrc"));
     migrator.setConfigFiles(QStringList() << QStringLiteral("kprivacyrc"));
     migrator.setUiFiles(QStringList() << QStringLiteral("sweeperui.rc"));
     migrator.migrate();
+#endif
 
    KAboutData aboutData(QStringLiteral("sweeper"), i18n("Sweeper"),
                         QStringLiteral(SWEEPER_VERSION),
@@ -45,8 +48,8 @@ int main(int argc, char *argv[])
    KAboutData::setApplicationData(aboutData);
    a.setWindowIcon(QIcon::fromTheme(QStringLiteral("trash-empty")));
 
-   parser.addOption(QCommandLineOption(QStringLiteral("automatic"),
-                    i18n("Sweeps without user interaction")));
+   const QCommandLineOption automaticOption(QStringLiteral("automatic"), i18n("Sweeps without user interaction"));
+   parser.addOption(automaticOption);
    aboutData.setupCommandLine(&parser);
    parser.process(a);
    aboutData.processCommandLine(&parser);
@@ -55,11 +58,11 @@ int main(int argc, char *argv[])
 
    // Application
    Sweeper *app;
-   if(parser.isSet(QStringLiteral("automatic"))) {
-      app = new Sweeper(true);
+   if (parser.isSet(automaticOption)) {
+       app = new Sweeper(true);
    } else {
-      app = new Sweeper(false);
-      app->show();
+       app = new Sweeper(false);
+       app->show();
    }
    return a.exec();
 }
